genotype_data: An example of genotype data for two genetic variants (SNPs)....

genotype_dataR Documentation

An example of genotype data for two genetic variants (SNPs). Here, genotype_data is a data.frame with the columns as SNPs (e.g., rs1 and rs2 here). The rows correspond to the 500 individuals in the same order as in the phenotype data.

Description

An example of genotype data for two genetic variants (SNPs). Here, genotype_data is a data.frame with the columns as SNPs (e.g., rs1 and rs2 here). The rows correspond to the 500 individuals in the same order as in the phenotype data.

Usage

data(genotype_data)

Format

A data.frame with the columns as SNPs (e.g., rs1 and rs2 here) and individuals in the rows with the same order as in the phenotype data:

Examples

data(genotype_data)
geno <- genotype_data

MPGE documentation built on March 12, 2026, 9:07 a.m.